@@ -6,21 +6,20 @@ import sys
 import biopandas.pdb
 
 import importlib.metadata
-
 import numpy as np
 
 import scipy.interpolate
 import scipy.optimize
 import scipy.spatial.transform
-import scipy.stats.qmc
 
 import rich.console
 import rich.logging
 import rich.progress
 
+import mrcfile
+
 import rigidbodyfit.arguments
 import rigidbodyfit.structure
-import rigidbodyfit.density
 
 
 def create_rich_logger():
@@ -166,6 +165,16 @@ class OverlapOptimiser:
 
         return -np.average(self.interpolator(mobile_rotated_shifted))
 
+def origin_vector(density):
+
+    origin = np.array(density.header.origin.tolist())
+
+    if np.all(origin == 0):
+        origin[0] = density.header.nxstart * density.voxel_size['x']
+        origin[1] = density.header.nystart * density.voxel_size['y']
+        origin[2] = density.header.nzstart * density.voxel_size['z']
+
+    return origin
 
 def run():
     """ run the command line interface """
@@ -187,10 +196,10 @@ def run():
     # read density data and determine voxel size and shift vector from it
     log.info("Reading density ...")
 
-    density = rigidbodyfit.density.read(command_line_arguments.density)
+    density = mrcfile.open(command_line_arguments.density)
     voxels = density.data.T
 
-    density_origin_vector = rigidbodyfit.density.origin_vector(density)
+    density_origin_vector = origin_vector(density)
     density_grid = tuple([
         density.voxel_size.tolist()[i] * np.arange(voxels.shape[i]) +
         density_origin_vector[i] for i in range(3)
